function BMS_DCM_MainExperiment(subjects,models)
% Compare different Dynamic Causal Models (DCMs) by means of random-effects
% Bayesian model selection (BMS) to identify the model that most accurately
% explains the measured data. Note that BMS is based on the negative free
% energy, which is a lower-bound approximation to the log model evidence 
% and takes into account model accuracy and complexity.
% 
% NOTE: For this script to run properly, SPM12 must be added to your MATLAB
% path. Also, you need to be in the folder where this script lies.
% 
% Input:
%   subjects      	-- subjects to be analyzed (if empty: use all subjects)
%   models      	-- models to be analyzed (if empty: use all models)
%
% Output:
% 
% 
% ----------------------------------------------------------------------
% 
% stefan_fraessle@gmx.de
%
% Author: Stefan Fraessle, TNU, UZH & ETHZ - 2019
% Copyright 2019 by Stefan Fraessle <stefan_fraessle@gmx.de>
%
% Licensed under GNU General Public License 3.0 or later.
% Some rights reserved. See COPYING, AUTHORS.
% 
% ----------------------------------------------------------------------


% specify folder name
foldername = pwd;
foldername = foldername(1:find(foldername=='/',1,'last')-1);

% initialize SPM version
spm('Defaults','fMRI');

% get the subject list
Subject_List = dir(fullfile(foldername,'Sub*'));

% define the name of the different models
name = {'model_contra_noINTER','model_contra_INTER'};

% select the subject to analyze
if ( isempty(subjects) )
    subject_analyze = 1:length(Subject_List);
else
    subject_analyze = subjects;
end

% select the subject to analyze
if ( isempty(models) )
    model_analyze = 1:length(name);
else
    model_analyze = models;
end


% set the foldername 
matlabbatch{1}.spm.dcm.bms.inference.dir{1} = [];

% define the BMS folder
BMS_folder = fullfile(foldername,'DCM_GroupAnalysis','Bayesian_model_selection');

% create the Bayesian model selection folder
if ( ~exist(BMS_folder,'dir') )
    mkdir(BMS_folder)
end

% asign the BMS folder
matlabbatch{1}.spm.dcm.bms.inference.dir{1} = BMS_folder;

% subject counter
s = 0;

% load all the models of all the subjects
for subject = subject_analyze
    
    % increase subject counter
    s = s + 1;
    
    % get the subject name
    Subject = Subject_List(subject).name;

    % define the folder where the SPM.mat (DCM regressors) is stored
    DCM_regressors_foldername = fullfile(foldername,Subject,'FirstLevel_DCM');
        
    % create entry for this subject
    matlabbatch{1}.spm.dcm.bms.inference.sess_dcm{s}.dcmmat = [];
        
    % asign the subjects models
    for model_number = model_analyze

        % get the filename
        filename = fullfile(DCM_regressors_foldername,['DCM_Motor_' name{model_number} '.mat']);
        
        % asign the filename of each model
        matlabbatch{1}.spm.dcm.bms.inference.sess_dcm{s}.dcmmat = [matlabbatch{1}.spm.dcm.bms.inference.sess_dcm{s}.dcmmat; {filename}];

    end
end

% don't use a model space file or an array with the negative free energies
matlabbatch{1}.spm.dcm.bms.inference.model_sp = {''};
matlabbatch{1}.spm.dcm.bms.inference.load_f   = {''};

% choose random-effects BMS/BMA
matlabbatch{1}.spm.dcm.bms.inference.method = 'RFX';

% no model families defined
matlabbatch{1}.spm.dcm.bms.inference.family_level.family_file = {''};

% do not perfom Bayesian model averaging
matlabbatch{1}.spm.dcm.bms.inference.bma.bma_no = 0;

% check whether data is correct
matlabbatch{1}.spm.dcm.bms.inference.verify_id = 1;


% save the matlabbatch
save(fullfile(BMS_folder,'BMS_comparison.mat'), 'matlabbatch');

% check if BMS file already exists
if ( exist(fullfile(BMS_folder,'BMS.mat'),'file') )
    delete(fullfile(BMS_folder,'BMS.mat'))
end

% run the matlabbatch
spm_jobman('run',matlabbatch)

end