function create_and_estimate_DCM_MainExperiment(subject,model)
% Creates a DCM structure from scratch by asigning the extracted BOLD signal 
% time series, as well as specifying the driving inputs and the model structure 
% (i.e., A, B, and C matrices). The function then estimates the respective DCM
% using standard routines from SPM.
% 
% NOTE: For this script to run properly, SPM12 must be added to your MATLAB
% path. Also, you need to be in the folder where this script lies.
% 
% Input:
%   subject      	-- subject to be analyzed
%   model           -- model to be analyzed
% 
% Output:
% 
% 
% ----------------------------------------------------------------------
% 
% stefan_fraessle@gmx.de
%
% Author: Stefan Fraessle, TNU, UZH & ETHZ - 2019
% Copyright 2019 by Stefan Fraessle <stefan_fraessle@gmx.de>
%
% Licensed under GNU General Public License 3.0 or later.
% Some rights reserved. See COPYING, AUTHORS.
% 
% ----------------------------------------------------------------------


% specify folder name
foldername = pwd;
foldername = foldername(1:find(foldername=='/',1,'last')-1);

% initialize SPM version
spm('Defaults','fMRI');

% define the name of the different models
name = {'model_contra_noINTER','model_contra_INTER'};

% get the subject list
Subject_List = dir(fullfile(foldername,'Sub*'));

% select the subject to analyze
if ( isempty(subject) )
    subject_analyze = 1:length(Subject_List);
else
    subject_analyze = subject;
end

% define the model to analyze
if ( isempty(model) )
    model_analyze = 1:length(name);
else
    model_analyze = model;
end

for s = subject_analyze

    % subject name
    Subject = Subject_List(s).name;

    % display progress
    disp(['-- Subject ' Subject ': Creating DCM Model Space -----------------'])

    % define the folder where the SPM.mat (DCM regressors) is stored
    DCM_regressors_foldername = fullfile(foldername,Subject,'FirstLevel_DCM');

    % define the folder where the VOIs are stored
    VOI_foldername = fullfile(foldername,Subject,'timeseries_VOI_adjusted');

    % get the filenames of VOIs
    VOI_files = [dir(fullfile(VOI_foldername,'VOI_M1*.mat')); dir(fullfile(VOI_foldername,'VOI_V1*.mat'))];


    % load the SPM.mat of the subject containing the DCM regressors etc.
    load(fullfile(foldername,Subject,'regressors','SPM.mat'));


    % specify the different models
    for model_number = model_analyze

        % define the vector that specifies which regressors enter model
        vector = [1 1 1];
        vector = (vector == 1);

        % clear the DCM structure
        clear DCM

        % load the VOI time series for all regions of interest
        for number_of_regions = 1:length(VOI_files)

            % load the files
            load(fullfile(VOI_foldername,VOI_files(number_of_regions).name),'xY');

            % asign the time series
            DCM.xY(number_of_regions).name  = xY.name;
            DCM.xY(number_of_regions).Ic    = xY.Ic;
            DCM.xY(number_of_regions).Sess  = xY.Sess;
            DCM.xY(number_of_regions).xyz   = xY.xyz;
            DCM.xY(number_of_regions).def   = xY.def;
            DCM.xY(number_of_regions).spec  = xY.spec;
            DCM.xY(number_of_regions).str   = xY.str;
            DCM.xY(number_of_regions).XYZmm = xY.XYZmm;
            DCM.xY(number_of_regions).X0    = xY.X0;
            DCM.xY(number_of_regions).y     = xY.y;
            DCM.xY(number_of_regions).u     = xY.u;
            DCM.xY(number_of_regions).v     = xY.v;
            DCM.xY(number_of_regions).s     = xY.s;

        end

        % number of regions
        DCM.n = length(DCM.xY);

        % number of time points
        DCM.v = length(DCM.xY(1).u);

        % confound matrix (constant and DCT)
        DCM.Y.X0 = DCM.xY(1).X0;

        % get the TR for the subject
        DCM.Y.dt    = SPM.xY.RT;

        % asign the time series
        for i = 1:DCM.n
            DCM.Y.y(:,i)  = DCM.xY(i).u;
            DCM.Y.name{i} = DCM.xY(i).name;
        end

        % specify error covariance matrices
        DCM.Y.Q = spm_Ce(ones(1,DCM.n)*DCM.v);

        % sampling rate and names of driving inputs
        DCM.U.dt   = SPM.Sess.U(1).dt;
        DCM.U.name = [SPM.Sess.U.name];
        DCM.U.name = DCM.U.name(vector);

        % define a temp array
        temp = [];

        % get the driving input regressors
        for number_of_regressors = 1:length(SPM.Sess.U)
            if ( vector(number_of_regressors) == 1 )
                temp = [temp SPM.Sess.U(number_of_regressors).u(33:end,1)];
            end
        end

        % asign the driving inputs
        DCM.U.u    = temp;

        % DCM parameters
        DCM.delays = repmat(SPM.xY.RT/2,DCM.n,1);
        DCM.TE     = 0.036;

        % DCM options
        DCM.options.nonlinear  = 0;
        DCM.options.two_state  = 0;
        DCM.options.stochastic = 0;
        DCM.options.centre     = 0;
        DCM.options.endogenous = 0;
        DCM.options.nograph    = 1;
        
        
        % specify the A matrix
        if ( model_number == 1 )
            DCM.a = [1 0 1; 0 1 1; 1 1 1];
        else
            DCM.a = [1 1 1; 1 1 1; 1 1 1];
        end
        
        % specify the B matrix
        DCM.b = zeros(size(DCM.a,1),size(DCM.a,2),size(DCM.U.u,2));
        if ( model_number == 1 )
            DCM.b(:,:,2) = [0 0 0; 0 0 1; 0 0 0];
            DCM.b(:,:,3) = [0 0 1; 0 0 0; 0 0 0];
        elseif ( model_number == 2 )
            DCM.b(:,:,2) = [0 1 0; 0 0 1; 0 0 0];
            DCM.b(:,:,3) = [0 0 1; 1 0 0; 0 0 0];
        end

        % specify the C matrix
        DCM.c = zeros(size(DCM.a,1),size(DCM.b,3));
        DCM.c(:,1) = [0 0 1]';

        % check if DCM results folder exists
        if ( ~exist(DCM_regressors_foldername,'dir') )
            mkdir(DCM_regressors_foldername)
        end
        
        % define the name of the DCM
        DCM_ToEstimate = fullfile(DCM_regressors_foldername,['DCM_Motor_' name{model_number} '.mat']);

        % save the DCM
        save(DCM_ToEstimate,'DCM');

        % display
        disp('')
        disp(['-- Subject ' Subject ': Estimation of Model ' name{model_number} ' -----------------'])
        disp('')

        % run model inversion of DCMs
        spm_dcm_estimate(DCM_ToEstimate);
        
    end
end

end