function extract_VOI_timeseries_MainExperiment(subject)
% Extract BOLD signal time series as the first eigenvariate from the
% regions of interest (ROIs) for each subject individually. Center
% coordinates of the individual ROIs are hard-coded and have been obtained
% from the first-level GLM analyses.
% 
% NOTE: This script is mainly for illustration purposes and will not run
% since the necessary data (first-level GLM, functional volumes) are not 
% provided.
% 
% Input:
%   subject      	-- subject to be analyzed
% 
% Output:
% 
% 
% ----------------------------------------------------------------------
% 
% stefan_fraessle@gmx.de
%
% Author: Stefan Fraessle, TNU, UZH & ETHZ - 2019
% Copyright 2019 by Stefan Fraessle <stefan_fraessle@gmx.de>
%
% Licensed under GNU General Public License 3.0 or later.
% Some rights reserved. See COPYING, AUTHORS.
% 
% ----------------------------------------------------------------------


% specify folder name
foldername = pwd;
foldername = foldername(1:find(foldername=='/',1,'last')-1);

% initialize spm
spm_jobman('initcfg')

% get the subject list
Subject_List = dir(fullfile(foldername,'Sub*'));

% ROI names of DCM
ROI_names = {'V1','M1_left','M1_right'};

% define the center coordinate
center_allregions = {[0 -80 -2],[-44 -18 60],[38 -20 70];...
    [0 -86 0],[-42 -16 52],[50 -20 62];...
    [4 -88 -4],[-34 -20 54],[44 -22 64];...
    [-4 -92 -4],[-40 -22 60],[48 -14 58];...
    [-10 -86 -10],[-36 -32 68],[40 -16 58];...
    [-14 -90 -4],[-42 -14 56],[40 -10 62]};

% define the contrast number
contrast_number = [11 9 7];

% select the subject to analyze
if ( isempty(subject) )
    subject_analyze = 1:length(Subject_List);
else
    subject_analyze = subject;
end


% display the progress
fprintf('\nExtract VoI time series...\n')

% iterate over all subjects
for s = subject_analyze
    
    % subject name
    Subject = Subject_List(s).name;
    
    % specify the effect of interest
    EoI_nr = 5; 

    % specify the SPM folder
    SPM_foldername = fullfile(foldername,Subject,'glm','Level1_0002');
    
    % time series folder
    timeseries_folder = fullfile(SPM_foldername,'timeseries_VOI_adjusted');
                    
    % check whether folder exists
    if ( ~exist(timeseries_folder,'dir') )
        mkdir(timeseries_folder)
    else
        delete(fullfile(timeseries_folder,'VOI*'))
    end

    % extract the time series for each region of interest
    for number_of_regions = 1:length(ROI_names)

        % load the batch for extracting the time series
        load(fullfile(foldername,'analysis','Batch_ExtractVOIs.mat'))

        % define the path where the SPM.mat can be found
        matlabbatch{1}.spm.util.voi.spmmat = cellstr(fullfile(SPM_foldername,'SPM.mat'));

        % choose an adjustment of the time series (effects of interest)
        matlabbatch{1}.spm.util.voi.adjust = EoI_nr;

        % choose session number
        matlabbatch{1}.spm.util.voi.session = 1;

        % set the name of the VOI
        matlabbatch{1}.spm.util.voi.name = ROI_names{number_of_regions};
        
        % use the SPM.mat specified above
        matlabbatch{1}.spm.util.voi.roi{1}.spm.spmmat = {''};

        % specify which contrast to use
        matlabbatch{1}.spm.util.voi.roi{1}.spm.contrast = contrast_number(number_of_regions);
        
        % only single contrast is used
        matlabbatch{1}.spm.util.voi.roi{1}.spm.conjunction = 1;
        
        % specify the threshold
        matlabbatch{1}.spm.util.voi.roi{1}.spm.threshdesc = 'none';
        matlabbatch{1}.spm.util.voi.roi{1}.spm.thresh     = 0.05;
        matlabbatch{1}.spm.util.voi.roi{1}.spm.extent     = 0;
        
        % no additional mask
        matlabbatch{1}.spm.util.voi.roi{1}.spm.mask = struct('contrast', {}, 'thresh', {}, 'mtype', {});
        
        % define the sphere from which the eigenvariate is extracted
        matlabbatch{1}.spm.util.voi.roi{2}.sphere.centre = center_allregions{s,number_of_regions};
        
        % define the radius of the sphere
        matlabbatch{1}.spm.util.voi.roi{2}.sphere.radius = 6;
        
        % don't jump to local / global maximum
        matlabbatch{1}.spm.util.voi.roi{2}.sphere.move.fixed = 1;
        
        % intersection of activation and sphere
        matlabbatch{1}.spm.util.voi.expression = 'i1 & i2';

        % run the batch and extract the time series
        spm_jobman('run',matlabbatch);
        
        % clear the matlabbatch
        clear matlabbatch
        
    end

    % move the extracted time series to the results folder
    movefile(fullfile(SPM_foldername,'VOI*.mat'),timeseries_folder)

    % delete the remaining files
    delete(fullfile(SPM_foldername,'VOI*'))
    
end

end